rem #
rem ## ONLY EDIT THIS FILE WHEN JOBSERVER IS SHUTDOWN!
rem #

rem ######################################################################
rem # JobServer needs these ports (choose ports greater than 1024
rem # and not used by any other application).
rem #
rem # webServerHttpPort     - HTTP port used by web GUI applications.
rem # webServerShutdownPort - Internally used port to shutdown webserver.
rem # containerRemotePort   - Internally used port number to communicate
rem #                         with JS container.
rem # agentPort             - Optional port is only required if using
rem #                         distributed job processing Agents running on
rem #                         remote hosts.
rem ######################################################################
set webServerHttpPort=8020
set webServerShutdownPort=8021
set containerRemotePort=8022
rem set agentPort=8024

rem #########################################################################################
rem # System database properties used by JobServer Container and Webserver
rem #
rem # Choose which database you are using. Currently supported databases
rem # are Oracle, Postgresql (PSQL), HSQL, and MYSQL
rem #
rem # dbDriverType    - Options are: ORACLE | ORACLE2 | PSQL | HSQL | MYSQL
rem #                    ORACLE2 supports Oracle RAC SCAN JDBC URL config.
rem #                    ORACLE supports standard SID based JDBC URL config.
rem # dbPort          - Port number used by database
rem # dbHost          - Name of host where db installed
rem # dbName          - Name of database (not applicable for HSQL) Note, for ORACLE
rem #                   this is the SID and for ORACLE2 this is the SERVICE_NAME.
rem # dbUsername      - Username for jdbc connection authentication
rem # dbPassword      - Password for jdbc connection authentication
rem # dbSchemaName    - Define name of JobServer schema (not applicable for HSQL and
rem #                   MYSQL). Do not set if no schema name is used for Oracle or
rem #                   Postgres database. You can use any unique schema name you
rem #                   like.
rem #
rem ##########################################################################################
set dbDriverType=ORACLE
set dbPort=1521
set dbHost=localhost
set dbName=somename
set dbUsername=jsuser
set dbPassword=changeme
rem set dbSchemaName=jobserver

rem ######################################################################
rem # These properties are necessary to configure for two purposes:
rem #   * When running JobServer's scheduling engine and webserver(s) on
rem #     seperate machines.
rem #   * Support for a failover scheduling engine which is run on seperate
rem #     host machine from the primary host machine scheduler.
rem #
rem # primarySchedServer   - Only necessary to set this if you plan to install
rem #                        JobServer Pro across multiple machines. This
rem #                        specifies the primary server where JobServer
rem #                        will run. Must also set this if you plan to
rem #                        install the webserver on a seperate host machine
rem #                        from the scheduling engine host machine.
rem # secondarySchedServer - Only necessary to this set if you want support
rem #                        for failover of JobServer's scheduling engine.
rem #                        This specifies host machine that will handle
rem #                        failover if the primary scheduling engine fails.
rem #
rem ######################################################################
rem set primarySchedServer=
rem set secondarySchedServer=

rem ##################################################################
rem # Advanced JVM settings for Webserver and JobServer Container.
rem #
rem # webServerJvmOptions    - JVM settings for webserver
rem # containerJvmOptions    - JVM settings for JobServer Container
rem # gwtCompilerJvmOptions  - JVM settings for GWT Compiler
rem # gwtCompilerThreads     - Number of threads used by GWT Compiler
rem #
rem #####################################################################
set webServerJvmOptions=-Xmx256m
set containerJvmOptions=-Xmx256m
set dbJvmOptions=-Xmx256m
set gwtCompilerJvmOptions=-Xmx256m
set gwtCompilerThreads=3
set gwtLogLevel=ERROR

rem #####################################################################
rem # JobServer database connection pool management properties. These
rem # values should be adjusted based on the number of concurrent users
rem # manually running/triggering Jobs.
rem #
rem # maxPoolSize is the maximum number of connections the pool will
rem # manage.
rem #
rem # holdPoolSize is the number of connections the pool will attempt
rem # to stay at when load is not excessive. Defaults to maxPoolSize 
rem # if not set.
rem #
rem # initPoolSize is the number of connections the pool will create
rem # on startup. Defaults to 1 if not set.
rem ######################################################################
set maxPoolSize=6
set holdPoolSize=3
set initPoolSize=1

rem ######################################################################
rem # WebServer database connection pool management properties. These
rem # values should be adjusted based on the number of concurrent users
rem # that are using the JobServer tools and applications.
rem #
rem # servletMaxPoolSize is the maximum number of connections the pool 
rem # will manage.
rem #
rem # servletHoldPoolSize is the number of connections the pool will 
rem # attempt to stay at when load is not excessive. Defaults to 
rem # servletMaxPoolSize if not set.
rem #
rem # servletInitPoolSize is the number of connections the pool will 
rem # create on startup. Defaults to 1 if not set.
rem #######################################################################
set servletMaxPoolSize=6
set servletHoldPoolSize=3
set servletInitPoolSize=1

rem ######################################################################
rem # This is an optional property for enabling or disabling Mule
rem # environment from within JobServer. If enabled then you may use Mule
rem # from within Tasklets using the MuleClient API and also host Mule
rem # service implementations from within JobServer. Enabling also
rem # allows Weblets to invoke Mule end points using the SOAFaces API
rem # from the UniversalClient GWT interface.
rem #
rem # useMule - set to true to enable, false to disable. Defaults to false.
rem #
rem ######################################################################
rem set useMule=false

rem ######################################################################
rem # Optional property for disabling JobServer scheduling container. This
rem # can be used to deploy environment where only weblets are used when
rem # no job or tasklet processing necessary.
rem #
rem # webletModeOnly - set to true if you plan to have one more webservers
rem #                  and do not need JobServer job processing features.
rem #                  False by default which means job processing is
rem #                  enabled.
rem #
rem ######################################################################
rem set webletModeOnly=false

rem ######################################################################
rem # LDAP authentication can be configured using this property. This
rem # allows username/passwords to be checked against LDAP system.
rem #
rem # ldapAuth - Set true to enable LDAP authentication. false for internal
rem #            jobserver database authentication. Detailed ldap
rem #            configuration options can be found in conf/ldap.properties
rem #            file.
rem #
rem ######################################################################
set ldapAuth=false

rem ######################################################################
rem # Secure all external passwords like database password and LDAP passwords.
rem #
rem # clearPW - Set false if you want database and LDAP passwords entered
rem #           in configuration files using encrypted format. Defaults to
rem #           true which leaves them in clear text.
rem #
rem ######################################################################
set clearPW=true

rem #########################################################################
rem # SSL/HTTPS setting for Web Server - set to "true" to enable SSL.
rem # When true use URL of "https://<your-machine-name>:<port>/jobserver"
rem # to access applications. You will need to also edit the file in
rem # jobserver\sys\app\conf\server.xml. Use serverSSL.xml as a
rem # replacement.
rem #
rem # It is recommended that you use a valid server certificate issued from
rem # a major certificate athority (e.g. verisign.com or thawte.com). Once
rem # you have been issued the certificate, place it in a the file
rem # "jobserver\conf\webserver.keystore" with the password "changeme".
rem #########################################################################
set useSSL=false

rem ######################################################################
rem # Debug settings for JobServer Container
rem # Normally debugging is not enabled in a production environment.
rem ######################################################################
set debug=false
set debugLevel=3
set debugClasses=ALL

rem ######################################################################
rem #         JobServer Environment Instance Version
rem # 
rem # WARNING: DO NOT EDIT THIS PROPERTY UNLESS YOU KNOW WHAT YOU ARE
rem #          DOING.
rem #
rem # The jsInstanceVersion property identifies a particular instance of
rem # of an environment installation. This allows for multiple instances
rem # of a JobServer environment to coexist on the same machine. By
rem # default the installation version ID is named "a".
rem #
rem # If you install another JobServer on the same machine
rem # call them "b", "c", ....etc. You may however use any ascii-numeric 
rem # character or string you like, so long as each instance has a unique
rem # name.
rem #
rem ######################################################################
set jsInstanceVersion=a

:end
